===============================
zipfreeinfo
===============================


.. image:: https://img.shields.io/pypi/v/zipfreeinfo.svg
        :target: https://pypi.python.org/pypi/zipfreeinfo

.. image:: https://img.shields.io/travis/marcelluseasley/zipfreeinfo.svg
        :target: https://travis-ci.org/marcelluseasley/zipfreeinfo

.. image:: https://readthedocs.org/projects/zipfreeinfo/badge/?version=latest
        :target: https://zipfreeinfo.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/marcelluseasley/zipfreeinfo/shield.svg
     :target: https://pyup.io/repos/github/marcelluseasley/zipfreeinfo/
     :alt: Updates


Provided a zip code, you are given information about that location.


* Free software: MIT license
* Documentation: https://zipfreeinfo.readthedocs.io.


Features
--------

* Provides city, state, latitude/longitude data for a given zip code

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

